@@ -1,14 +1,11 @@
-/***************************************************************************
- *   Copyright (C) 2013 by Albert Astals Cid <aacid@kde.org>               *
- *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
- *                         company, info@kdab.com. Work sponsored by the   *
- *                         LiMux project of the city of Munich             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2013 Albert Astals Cid <aacid@kde.org>
+
+    Work sponsored by the LiMux project of the city of Munich:
+    SPDX-FileCopyrightText: 2017 Klarälvdalens Datakonsult AB a KDAB Group company <info@kdab.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // clazy:excludeall=qstring-allocations
 
@@ -775,8 +772,9 @@ void PartTest::testeRectSelectionStartingOnLinks()
     Okular::Part part(nullptr, nullptr, dummyArgs);
     QVERIFY(openDocument(&part, QStringLiteral(KDESRCDIR "data/pdf_with_links.pdf")));
     // hide info messages as they interfere with selection area
+    Okular::Settings::self()->setShowEmbeddedContentMessages(false);
     Okular::Settings::self()->setShowOSD(false);
-    ;
+
     part.widget()->show();
     QVERIFY(QTest::qWaitForWindowExposed(part.widget()));
 
